/// <amd-module name="@typedorm/common/src/table" />
import { INDEX_TYPE } from './enums';
import { CompositePrimaryKey } from './metadata/metadata-storage';
export declare const IsCompositePrimaryKey: (key: unknown) => key is CompositePrimaryKey;
export interface TableOptions {
    name: string;
    partitionKey: string;
    sortKey?: string;
    indexes?: {
        [key: string]: IndexOptions;
    };
}
export interface GSIIndexOptions {
    type: INDEX_TYPE.GSI;
    partitionKey: string;
    sortKey: string;
    /**
     * DynamoDB only adds item to index if both Partition Key and Sort Key defined
     * for any given GSI contains value
     *
     * Indexes missing sort key value will not be added to index.
     */
    isSparse?: boolean;
}
export interface LSIIndexOptions {
    type: INDEX_TYPE.LSI;
    sortKey: string;
    isSparse?: boolean;
}
export declare type IndexOptions = GSIIndexOptions | LSIIndexOptions;
export declare class Table {
    private options;
    constructor(options: TableOptions);
    set name(value: string);
    get name(): string;
    get partitionKey(): string;
    get sortKey(): string;
    usesCompositeKey(): boolean;
    getIndexByKey(key: string): IndexOptions;
}
